Crate spade_ast_lowering

Crate spade_ast_lowering 

Modules

builtins
error
global_symbols
id_tracker
pipelines
testutil
types

Structs

Context

Enums

SelfContext
TypeSpecKind
The context in which a type expression occurs. This controls what hir::TypeExpressions an ast::TypeExpression can be lowered to

Functions

ensure_unique_anonymous_traits
Ensures that there are no functions in anonymous trait impls that have conflicting names
re_visit_type_param
Visit an AST type parameter, converting it to a HIR type parameter. The name is not added to the symbol table as this function is re-used for both global symbol collection and normal HIR lowering.
unit_head
Visit the head of an entity to generate an entity head
visit_call_kind
visit_const_generic
visit_expression
visit_item
visit_module
visit_module_body
visit_pattern
visit_trait_spec
visit_turbofish
visit_type_expression
visit_type_param
Visit an AST type parameter, converting it to a HIR type parameter and adding it to the symbol table
visit_type_spec
visit_unit
The extra_path parameter allows specifying an extra path prepended to the name of the entity. This is used by impl blocks to append a unique namespace
visit_unit_kind
visit_where_clauses