Modules
Structs
Enums
- Self
Context - Type
Spec Kind - The context in which a type expression occurs. This controls what hir::TypeExpressions an ast::TypeExpression can be lowered to
Functions
- ensure_
unique_ anonymous_ traits - Ensures that there are no functions in anonymous trait impls that have conflicting names
- re_
visit_ type_ param - Visit an AST type parameter, converting it to a HIR type parameter. The name is not added to the symbol table as this function is re-used for both global symbol collection and normal HIR lowering.
- unit_
head - Visit the head of an entity to generate an entity head
- visit_
call_ kind - visit_
const_ generic - visit_
expression - visit_
item - visit_
module - visit_
module_ body - visit_
pattern - visit_
trait_ spec - visit_
turbofish - visit_
type_ expression - visit_
type_ param - Visit an AST type parameter, converting it to a HIR type parameter and adding it to the symbol table
- visit_
type_ spec - visit_
unit - The
extra_pathparameter allows specifying an extra path prepended to the name of the entity. This is used by impl blocks to append a unique namespace - visit_
unit_ kind - visit_
where_ clauses